@@ -18,10 +18,10 @@ constructs:
 
 Notes
 -----
-Except for the `Point` and `Vector` classes which will be
-discussed below, all of the other classes define a `__getitem__` method that can
-be used to retreive the points defining the `GeometricObject` by
-indices.
+
+Except for the `Point` and `Vector` classes which will be discussed below, all
+of the other classes define a `__getitem__` method that can be used to retreive
+the points defining the `GeometricObject` by indices.
 
 The `Point` class defines the `__getitem__` method in a sperate way,
 i.e. it returns the Cartesian coordinates of the `Point` by indinces.
@@ -177,6 +177,7 @@ class GeometricObject(object):
             radians. Default is degrees.
         """
 
+        polygon_list = None
         if isinstance(self, Polygon):
             # we don't want to include the last point since that's also the
             # first point and if we were to rotate it, it would end up being
@@ -190,7 +191,8 @@ class GeometricObject(object):
         for p in self[sl]:
             # rotate each individual point
             p.rotate(theta, point, angle)
-            polygon_list.append(p)
+            if polygon_list is not None:
+                polygon_list.append(p)
         if polygon_list:
             # in the case of Polygon we build a new rotated one
             self = Polygon(polygon_list)
@@ -434,7 +436,7 @@ class Point(GeometricObject):
         self._x = x
         self._y = y
 
-    def rotate(self, theta, point=None, angle='radians'):
+    def rotate(self, theta, point=None, angle='degrees'):
         """
         Rotate `self` by angle theta.
 
@@ -443,8 +445,8 @@ class Point(GeometricObject):
         theta : scalar
             Angle to rotate by. Default in radians (see `angle`).
         point : {None, point-like}, optional
-            Pivot point to rotate against (instead of origin). If not given, the
-            point will be rotated against origin.
+            Pivot point to rotate against (instead of origin). If not given,
+            the point will be rotated against origin.
         angle : {'radians', 'degrees'}, optional
             How is `theta` passed? in radians or degrees.
         """
